@@ -7,13 +7,12 @@ import lammps_step
 
 class CustomStep(object):
     my_description = {
-        'description':
-            (
-                'A custom step for LAMMPS, where the user types in LAMMPS '
-                'commmands directly'
-            ),
-        'group': 'Customize',
-        'name': 'Custom'
+        "description": (
+            "A custom step for LAMMPS, where the user types in LAMMPS "
+            "commmands directly"
+        ),
+        "group": "Customize",
+        "name": "Custom",
     }
 
     def __init__(self, flowchart=None, gui=None):
@@ -24,8 +23,7 @@ class CustomStep(object):
         pass
 
     def description(self):
-        """Return a description of what this extension does
-        """
+        """Return a description of what this extension does"""
         return CustomStep.my_description
 
     def create_node(self, flowchart=None, **kwargs):
