@@ -7,13 +7,12 @@ import lammps_step
 
 class InitializationStep(object):
     my_description = {
-        'description':
-            (
-                'The initialization of LAMMPS, specifying e.g. nonbond '
-                'methods and cutoffs'
-            ),
-        'group': 'Calculations',
-        'name': 'Initialization'
+        "description": (
+            "The initialization of LAMMPS, specifying e.g. nonbond "
+            "methods and cutoffs"
+        ),
+        "group": "Calculations",
+        "name": "Initialization",
     }
 
     def __init__(self, flowchart=None, gui=None):
@@ -24,8 +23,7 @@ class InitializationStep(object):
         pass
 
     def description(self):
-        """Return a description of what this extension does
-        """
+        """Return a description of what this extension does"""
         return InitializationStep.my_description
 
     def create_node(self, flowchart=None, **kwargs):
