@@ -127,8 +127,8 @@ quantity_to_dimensionality = {
     ],
     "velocity": ["[length] / [time]"],
     "force": [
-        "[length] * [mass] / [substance] / [time] ** 2",
-        "[length] * [mass] / [time] ** 2",
+        "[mass] * [length] / [time] ** 2 / [substance]",
+        "[mass] * [length] / [time] ** 2",
     ],
     "torque": [
         "[length] ** 2 * [mass] / [substance] / [time] ** 2",
@@ -156,10 +156,13 @@ dimensionality_to_quantity = {
     "[length]": ["distance"],
     "[time]": ["time"],
     "[length] ** 2 * [mass] / [substance] / [time] ** 2": ["energy", "torque"],
+    "[mass] * [length] ** 2 / [time] ** 2 / [substance]": ["energy", "torque"],
     "[length] ** 2 * [mass] / [time] ** 2": ["energy", "torque"],
     "[length] / [time]": ["velocity"],
     "[length] * [mass] / [substance] / [time] ** 2": ["force"],
     "[length] * [mass] / [time] ** 2": ["force"],
+    "[mass] * [length] / [time] ** 2 / [substance]": ["force"],
+    "[mass] * [length] / [time] ** 2": ["force"],
     "[temperature]": ["temperature"],
     "[mass] / [length] / [time] ** 2": ["pressure"],
     "[mass] / [length] / [time]": ["dynamic viscosity"],
@@ -181,9 +184,8 @@ def set_lammps_unit_system(value):
     lammps_unit_system = value
 
 
-def get_lammps_unit_system(value):
+def get_lammps_unit_system():
     """Get the default unit system for LAMMPS."""
-    global lammps_unit_system
     return lammps_unit_system
 
 
@@ -224,6 +226,16 @@ def from_lammps_units(value, units, quantity=None, unit_system=None):
     return converted
 
 
+def lammps_units(quantity, unit_system=None):
+    """Return the current LAMMPS units for the given quantity."""
+    if unit_system is None:
+        unit_system = lammps_unit_system
+
+    unit_expr = unit_systems[unit_system][quantity]
+
+    return unit_expr
+
+
 if __name__ == "__main__":  # pragma: no cover
     import pint
     import json
