@@ -2,9 +2,10 @@
 
 """The graphical part of a LAMMPS velocities step"""
 
+import tkinter as tk
+
 import seamm
 import seamm_widgets as sw
-import tkinter as tk
 
 
 class TkVelocities(seamm.TkNode):
@@ -59,9 +60,9 @@ class TkVelocities(seamm.TkNode):
             widgets.append(self[key])
             row += 1
 
-        if "scaling" in method:
+        if "scaling" not in method:
             self["seed"].grid(row=row, column=0, sticky=tk.EW)
             widgets.append(self["seed"])
             row += 1
 
-            sw.align_labels(widgets)
+            sw.align_labels(widgets, sticky=tk.E)
